@@ -13,7 +13,7 @@
 
 #include "kaevent.h"
 
-#include <attribute.h>
+#include <Akonadi/Attribute>
 
 namespace KAlarmCal
 {
